# frozen_string_literal: true

require './lib/storage/algolia/base'

module Storage
  module Algolia
    module Actions
      class Create < ::Storage::Algolia::Base
        attr_reader :model_name, :params

        def initialize(model_name:, params:)
          @model_name = model_name
          @params = params
        end

        def process
          raise Exception unless task.dig('objectID')

          normalize params.to_hash.merge(
            objectID: task.dig('objectID'),
            updatedAt: task.dig('updatedAt')
          )
        end

        private

        def task
          @task ||= index.save_object(payload)
        end

        def payload
          { objectID: SecureRandom.uuid }.merge(params)
        end

        def uuid
          @uuid ||= ::SecureRandom.uuid
        end
      end
    end
  end
end