# frozen_string_literal: true

require './lib/storage/algolia/base'

module Storage
  module Algolia
    module Actions
      class Update < ::Storage::Algolia::Base
        attr_reader :model_name, :params, :id, :retries

        def initialize(model_name:, params:, id:)
          @model_name = model_name
          @params = params
          @id = id
          @retries = 0
        end

        def process
          raise Exception unless task.dig('objectID')

          normalize original_object.to_hash.merge(
            {
              objectID: task.dig('objectID'),
              updatedAt: task.dig('updatedAt')
            },
            params
          )
        end

        private

        def original_object
          @original_object ||= ::Storage::Algolia::Actions::Get.process(
            model_name: model_name,
            id: id
          )
        end

        def task
          @task ||= index.partial_update_object(params, id)
        end
      end
    end
  end
end
