# frozen_string_literal: true

require './lib/storage/application_service'
require 'algoliasearch'
require 'hashugar'
require 'active_support/core_ext/hash/except'
require 'active_support/core_ext/hash/keys'
require 'dotenv/load'
::Dotenv.load

module Storage
  module Algolia
    class Base < ::ApplicationService
      private

      def index
        @index ||= begin
          ::Algolia.init(
            application_id: algolia_application_id,
            api_key: algolia_admin_api_key
          )
          ::Algolia::Index.new(model_name.to_s)
        end
      end

      def normalize(data)
        ::Algolia::NormalizeId.process(data)
      end

      def params
        NoMethodError
      end

      def model_name
        NoMethodError
      end

      def algolia_application_id
        ENV['ALGOLIA_APPLICATION_ID'] ||
          raise(Exception, 'Missing algolia application id')
      end

      def algolia_admin_api_key
        ENV['ALGOLIA_ADMIN_API_KEY'] ||
          raise(Exception, 'Missing algolia admin api key')
      end
    end
  end
end
